build_bundle_scope

Function build_bundle_scope 

pub fn build_bundle_scope(
    root: &Path,
    custom_ignore_file: Option<&Path>,
) -> Result<BundleScope>
Analyze an agent crate and return the source scope mdx-rust may inspect. Builds the set of files we care about + runs finders on them.