pub fn find_run_agent_functions(source: &str) -> Vec<AgentEntrypoint>Expand description
Rust source finders used to identify prompts, tools, and entrypoints. Find functions that look like agent entrypoints (run_agent, run, main agent fn).
pub fn find_run_agent_functions(source: &str) -> Vec<AgentEntrypoint>Rust source finders used to identify prompts, tools, and entrypoints. Find functions that look like agent entrypoints (run_agent, run, main agent fn).