pub fn find_tools(source: &str, file_path: &Path) -> Vec<ExtractedTool>Expand description
Rust source finders used to identify prompts, tools, and entrypoints. Very rough tool extraction (looks for .tool( or tool definitions).
pub fn find_tools(source: &str, file_path: &Path) -> Vec<ExtractedTool>Rust source finders used to identify prompts, tools, and entrypoints. Very rough tool extraction (looks for .tool( or tool definitions).