pub struct AgentBundle {
pub scope: BundleScope,
pub preambles: Vec<ExtractedPrompt>,
pub tools: Vec<ExtractedTool>,
pub is_rig_agent: bool,
pub key_files: Vec<PathBuf>,
}Expand description
Analyze an agent crate and return the source scope mdx-rust may inspect. Rich analysis result for an agent. This is what gets summarized and sent to the LLM for high-quality diagnosis.
Fields
scope: BundleScopepreambles: Vec<ExtractedPrompt>tools: Vec<ExtractedTool>is_rig_agent: boolkey_files: Vec<PathBuf>Trait Implementations
Sourceimpl Clone for AgentBundle
impl Clone for AgentBundle
Sourcefn clone(&self) -> AgentBundle
fn clone(&self) -> AgentBundle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentBundle
impl Debug for AgentBundle
Sourceimpl Default for AgentBundle
impl Default for AgentBundle
Sourcefn default() -> AgentBundle
fn default() -> AgentBundle
Returns the “default value” for a type. Read more