pub struct HardeningAnalysis {
pub root: PathBuf,
pub target: Option<PathBuf>,
pub files_scanned: usize,
pub findings: Vec<HardeningFinding>,
pub changes: Vec<HardeningFileChange>,
}Expand description
Conservative Rust hardening analysis for ordinary Rust modules.
Fields
root: PathBuftarget: Option<PathBuf>files_scanned: usizefindings: Vec<HardeningFinding>changes: Vec<HardeningFileChange>Trait Implementations
Sourceimpl Clone for HardeningAnalysis
impl Clone for HardeningAnalysis
Sourcefn clone(&self) -> HardeningAnalysis
fn clone(&self) -> HardeningAnalysis
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HardeningAnalysis
impl Debug for HardeningAnalysis
Sourceimpl<'de> Deserialize<'de> for HardeningAnalysis
impl<'de> Deserialize<'de> for HardeningAnalysis
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HardeningAnalysis
impl JsonSchema for HardeningAnalysis
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HardeningAnalysis
impl RefUnwindSafe for HardeningAnalysis
impl Send for HardeningAnalysis
impl Sync for HardeningAnalysis
impl Unpin for HardeningAnalysis
impl UnsafeUnpin for HardeningAnalysis
impl UnwindSafe for HardeningAnalysis