pub struct HardeningFileChange {
pub file: PathBuf,
pub old_content: String,
pub new_content: String,
pub strategy: HardeningStrategy,
pub finding_ids: Vec<String>,
pub description: String,
}Expand description
Conservative Rust hardening analysis for ordinary Rust modules.
Fields
file: PathBufold_content: Stringnew_content: Stringstrategy: HardeningStrategyfinding_ids: Vec<String>description: StringTrait Implementations
Sourceimpl Clone for HardeningFileChange
impl Clone for HardeningFileChange
Sourcefn clone(&self) -> HardeningFileChange
fn clone(&self) -> HardeningFileChange
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HardeningFileChange
impl Debug for HardeningFileChange
Sourceimpl<'de> Deserialize<'de> for HardeningFileChange
impl<'de> Deserialize<'de> for HardeningFileChange
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HardeningFileChange
impl JsonSchema for HardeningFileChange
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HardeningFileChange
impl RefUnwindSafe for HardeningFileChange
impl Send for HardeningFileChange
impl Sync for HardeningFileChange
impl Unpin for HardeningFileChange
impl UnsafeUnpin for HardeningFileChange
impl UnwindSafe for HardeningFileChange