pub struct HardeningFinding {
pub id: String,
pub title: String,
pub description: String,
pub file: PathBuf,
pub line: usize,
pub strategy: HardeningStrategy,
pub patchable: bool,
}Expand description
Conservative Rust hardening analysis for ordinary Rust modules.
Fields
id: Stringtitle: Stringdescription: Stringfile: PathBufline: usizestrategy: HardeningStrategypatchable: boolTrait Implementations
Sourceimpl Clone for HardeningFinding
impl Clone for HardeningFinding
Sourcefn clone(&self) -> HardeningFinding
fn clone(&self) -> HardeningFinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HardeningFinding
impl Debug for HardeningFinding
Sourceimpl<'de> Deserialize<'de> for HardeningFinding
impl<'de> Deserialize<'de> for HardeningFinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HardeningFinding
impl JsonSchema for HardeningFinding
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HardeningFinding
impl RefUnwindSafe for HardeningFinding
impl Send for HardeningFinding
impl Sync for HardeningFinding
impl Unpin for HardeningFinding
impl UnsafeUnpin for HardeningFinding
impl UnwindSafe for HardeningFinding