pub struct PublicItemSummary {
pub kind: String,
pub name: String,
pub line: usize,
}Expand description
Plan-first refactor analysis for ordinary Rust modules.
Fields
kind: Stringname: Stringline: usizeTrait Implementations
Sourceimpl Clone for PublicItemSummary
impl Clone for PublicItemSummary
Sourcefn clone(&self) -> PublicItemSummary
fn clone(&self) -> PublicItemSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PublicItemSummary
impl Debug for PublicItemSummary
Sourceimpl<'de> Deserialize<'de> for PublicItemSummary
impl<'de> Deserialize<'de> for PublicItemSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PublicItemSummary
impl JsonSchema for PublicItemSummary
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PublicItemSummary
impl RefUnwindSafe for PublicItemSummary
impl Send for PublicItemSummary
impl Sync for PublicItemSummary
impl Unpin for PublicItemSummary
impl UnsafeUnpin for PublicItemSummary
impl UnwindSafe for PublicItemSummary