pub struct RefactorAnalysis {
pub root: PathBuf,
pub target: Option<PathBuf>,
pub files_scanned: usize,
pub files: Vec<RefactorFileSummary>,
pub module_edges: Vec<ModuleEdge>,
}Expand description
Plan-first refactor analysis for ordinary Rust modules.
Fields
root: PathBuftarget: Option<PathBuf>files_scanned: usizefiles: Vec<RefactorFileSummary>module_edges: Vec<ModuleEdge>Trait Implementations
Sourceimpl Clone for RefactorAnalysis
impl Clone for RefactorAnalysis
Sourcefn clone(&self) -> RefactorAnalysis
fn clone(&self) -> RefactorAnalysis
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RefactorAnalysis
impl Debug for RefactorAnalysis
Sourceimpl<'de> Deserialize<'de> for RefactorAnalysis
impl<'de> Deserialize<'de> for RefactorAnalysis
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RefactorAnalysis
impl JsonSchema for RefactorAnalysis
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RefactorAnalysis
impl RefUnwindSafe for RefactorAnalysis
impl Send for RefactorAnalysis
impl Sync for RefactorAnalysis
impl Unpin for RefactorAnalysis
impl UnsafeUnpin for RefactorAnalysis
impl UnwindSafe for RefactorAnalysis