pub struct RefactorFileSummary {
pub file: PathBuf,
pub line_count: usize,
pub function_count: usize,
pub public_item_count: usize,
pub largest_function_lines: usize,
pub has_tests: bool,
pub public_items: Vec<PublicItemSummary>,
}Expand description
Plan-first refactor analysis for ordinary Rust modules.
Fields
file: PathBufline_count: usizefunction_count: usizepublic_item_count: usizelargest_function_lines: usizehas_tests: boolpublic_items: Vec<PublicItemSummary>Trait Implementations
Sourceimpl Clone for RefactorFileSummary
impl Clone for RefactorFileSummary
Sourcefn clone(&self) -> RefactorFileSummary
fn clone(&self) -> RefactorFileSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RefactorFileSummary
impl Debug for RefactorFileSummary
Sourceimpl<'de> Deserialize<'de> for RefactorFileSummary
impl<'de> Deserialize<'de> for RefactorFileSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RefactorFileSummary
impl JsonSchema for RefactorFileSummary
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RefactorFileSummary
impl RefUnwindSafe for RefactorFileSummary
impl Send for RefactorFileSummary
impl Sync for RefactorFileSummary
impl Unpin for RefactorFileSummary
impl UnsafeUnpin for RefactorFileSummary
impl UnwindSafe for RefactorFileSummary